/*
 * lcd_map.inc
 *
 *  Created on: 24.03.2019
 *      Author: harry
 *
 *      Memory-mapping für various LCD-Displays
 */

/**********************************************************************************
 * 4 x 20 with HD44780
 **********************************************************************************/

#if LCD_TYPE == LCD20X4
#define LCD_COLUMNS 20
#define LCD_LINES 	4

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x28
#define LCD_FONT_HIGHT		8

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c,
		0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13 },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c,
		0x4d, 0x4e, 0x4f, 0x50, 0x51, 0x52, 0x53 },
{ 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f, 0x20,
		0x21, 0x22, 0x23, 0x24, 0x25, 0x26, 0x27 },
{ 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e, 0x5f, 0x60,
		0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67 } };

#endif

/**********************************************************************************
 * 2 x 16 with HD44780
 **********************************************************************************/

#if LCD_TYPE == LCD16X2
#define LCD_COLUMNS 16
#define LCD_LINES 	2

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x28
#define LCD_FONT_HIGHT		8

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c,
		0x0d, 0x0e, 0x0f },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c,
		0x4d, 0x4e, 0x4f } };

#endif

/**********************************************************************************
 * 2 x 16 with RS0010
 **********************************************************************************/

#if LCD_TYPE == LCD16X2_OLED	// RS0010 Controller
#define LCD_COLUMNS 16
#define LCD_LINES 	2

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x29
#define LCD_FONT_HIGHT		8

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c,
		0x0d, 0x0e, 0x0f },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c,
		0x4d, 0x4e, 0x4f } };

#endif

/**********************************************************************************
 * 2 x 20 with HD44780
 **********************************************************************************/

#if LCD_TYPE == LCD20X2
#define LCD_COLUMNS 20
#define LCD_LINES 	2

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x28
#define LCD_FONT_HIGHT		8

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c,
		0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13 },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c,
		0x4d, 0x4e, 0x4f, 0x50, 0x51, 0x52, 0x53 } };
#endif

/**********************************************************************************
 * 2 x 8 with HD44780
 **********************************************************************************/

#if LCD_TYPE == LCD8X2
#define LCD_COLUMNS 8
#define LCD_LINES 	2

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x28
#define LCD_FONT_HIGHT		8

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07 },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47 };

#endif

/**********************************************************************************
 * 2 x 8 with RS0010
 **********************************************************************************/

#if LCD_TYPE == LCD8X2_OLED
#define LCD_COLUMNS 8
#define LCD_LINES 	2
#define LCD_FONT_HIGHT		8

#define LCD_ENTRYMODESET    0x06
#define LCD_FUNCTIONSET     0x29

static const uint8_t lcd_map[LCD_LINES][LCD_COLUMNS] =
{
{ 0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07 },
{ 0x40, 0x41, 0x42, 0x43, 0x44, 0x45, 0x46, 0x47 };

#endif
